Compatibility re-exports for SQL migration planning types.
Structs
- Column
ToAdd - A column missing from an existing table and planned for additive creation.
- Index
ToCreate - A standalone index missing from the database and planned for creation.
- Migration
Statement - A SQL statement emitted by a migration plan.
- Schema
Migration Plan - Additive schema changes planned for a live database.
- Table
ToCreate - A table missing from the database and planned for creation.
Enums
- Migration
Statement Kind - The additive operation represented by a migration statement.
- Schema
Migration Warning - Non-executable findings discovered while planning migrations.