pub struct ColumnToAdd {
pub table_logical_name: String,
pub table_name: String,
pub field_logical_name: String,
pub column_name: String,
}Expand description
A column missing from an existing table and planned for additive creation.
Fields
table_logical_name: Stringtable_name: Stringfield_logical_name: Stringcolumn_name: StringTrait Implementations
Sourceimpl Clone for ColumnToAdd
impl Clone for ColumnToAdd
Sourcefn clone(&self) -> ColumnToAdd
fn clone(&self) -> ColumnToAdd
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ColumnToAdd
impl Debug for ColumnToAdd
Sourceimpl<'de> Deserialize<'de> for ColumnToAdd
impl<'de> Deserialize<'de> for ColumnToAdd
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<ColumnToAdd, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<ColumnToAdd, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for ColumnToAdd
impl PartialEq for ColumnToAdd
Sourcefn eq(&self, other: &ColumnToAdd) -> bool
fn eq(&self, other: &ColumnToAdd) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for ColumnToAdd
impl Serialize for ColumnToAdd
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl Eq for ColumnToAdd
impl StructuralPartialEq for ColumnToAdd