pub struct IndexToCreate {
pub table_logical_name: String,
pub table_name: String,
pub field_logical_name: String,
pub column_name: String,
pub index_name: String,
}Expand description
A standalone index missing from the database and planned for creation.
Fields
table_logical_name: Stringtable_name: Stringfield_logical_name: Stringcolumn_name: Stringindex_name: StringTrait Implementations
Sourceimpl Clone for IndexToCreate
impl Clone for IndexToCreate
Sourcefn clone(&self) -> IndexToCreate
fn clone(&self) -> IndexToCreate
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for IndexToCreate
impl Debug for IndexToCreate
Sourceimpl<'de> Deserialize<'de> for IndexToCreate
impl<'de> Deserialize<'de> for IndexToCreate
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<IndexToCreate, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<IndexToCreate, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for IndexToCreate
impl PartialEq for IndexToCreate
Sourcefn eq(&self, other: &IndexToCreate) -> bool
fn eq(&self, other: &IndexToCreate) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for IndexToCreate
impl Serialize for IndexToCreate
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl Eq for IndexToCreate
impl StructuralPartialEq for IndexToCreate