pub struct TableToCreate {
pub logical_name: String,
pub table_name: String,
}Expand description
A table missing from the database and planned for creation.
Fields
logical_name: Stringtable_name: StringTrait Implementations
Sourceimpl Clone for TableToCreate
impl Clone for TableToCreate
Sourcefn clone(&self) -> TableToCreate
fn clone(&self) -> TableToCreate
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TableToCreate
impl Debug for TableToCreate
Sourceimpl<'de> Deserialize<'de> for TableToCreate
impl<'de> Deserialize<'de> for TableToCreate
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<TableToCreate, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<TableToCreate, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for TableToCreate
impl PartialEq for TableToCreate
Sourcefn eq(&self, other: &TableToCreate) -> bool
fn eq(&self, other: &TableToCreate) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for TableToCreate
impl Serialize for TableToCreate
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl Eq for TableToCreate
impl StructuralPartialEq for TableToCreate